@@ -12,13 +12,13 @@
 #include "adw-animation-util.h"
 #include "adw-action-row.h"
 #include "adw-leaflet.h"
-#include "adw-macros-private.h"
 #include "adw-preferences-group-private.h"
 #include "adw-preferences-page-private.h"
 #include "adw-toast-overlay.h"
 #include "adw-view-switcher.h"
 #include "adw-view-switcher-bar.h"
 #include "adw-view-switcher-title.h"
+#include "adw-widget-utils-private.h"
 
 /**
  * AdwPreferencesWindow:
@@ -37,8 +37,6 @@
  *
  * `AdwPreferencesWindow` has a main CSS node with the name `window` and the
  * style class `.preferences`.
- *
- * Since: 1.0
  */
 
 typedef struct
@@ -568,8 +566,6 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
    * AdwViewStack:visible-page: (attributes org.gtk.Property.get=adw_preferences_window_get_visible_page org.gtk.Property.set=adw_preferences_window_set_visible_page)
    *
    * The currently visible page.
-   *
-   * Since: 1.0
    */
   props[PROP_VISIBLE_PAGE] =
     g_param_spec_object ("visible-page", NULL, NULL,
@@ -582,8 +578,6 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
    * The name of the currently visible page.
    *
    * See [property@ViewStack:visible-child].
-   *
-   * Since: 1.0
    */
   props[PROP_VISIBLE_PAGE_NAME] =
     g_param_spec_string ("visible-page-name", NULL, NULL,
@@ -594,8 +588,6 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
    * AdwPreferencesWindow:search-enabled: (attributes org.gtk.Property.get=adw_preferences_window_get_search_enabled org.gtk.Property.set=adw_preferences_window_set_search_enabled)
    *
    * Whether search is enabled.
-   *
-   * Since: 1.0
    */
   props[PROP_SEARCH_ENABLED] =
     g_param_spec_boolean ("search-enabled", NULL, NULL,
@@ -617,8 +609,6 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
    * <kbd>Alt</kbd>+<kbd>←</kbd> shortcut.
    *
    * For right-to-left locales, gestures and shortcuts are reversed.
-   *
-   * Since: 1.0
    */
   props[PROP_CAN_NAVIGATE_BACK] =
     g_param_spec_boolean ("can-navigate-back", NULL, NULL,
@@ -725,8 +715,6 @@ adw_preferences_window_buildable_init (GtkBuildableIface *iface)
  * Creates a new `AdwPreferencesWindow`.
  *
  * Returns: the newly created `AdwPreferencesWindow`
- *
- * Since: 1.0
  */
 GtkWidget *
 adw_preferences_window_new (void)
@@ -740,8 +728,6 @@ adw_preferences_window_new (void)
  * @page: the page to add
  *
  * Adds a preferences page to @self.
- *
- * Since: 1.0
  */
 void
 adw_preferences_window_add (AdwPreferencesWindow *self,
@@ -769,8 +755,6 @@ adw_preferences_window_add (AdwPreferencesWindow *self,
  * @page: the page to remove
  *
  * Removes a page from @self.
- *
- * Since: 1.0
  */
 void
 adw_preferences_window_remove (AdwPreferencesWindow *self,
@@ -796,8 +780,6 @@ adw_preferences_window_remove (AdwPreferencesWindow *self,
  * Gets the currently visible page of @self.
  *
  * Returns: (transfer none) (nullable): the visible page
- *
- * Since: 1.0
  */
 AdwPreferencesPage *
 adw_preferences_window_get_visible_page (AdwPreferencesWindow *self)
@@ -817,8 +799,6 @@ adw_preferences_window_get_visible_page (AdwPreferencesWindow *self)
  * @page: a page of @self
  *
  * Makes @page the visible page of @self.
- *
- * Since: 1.0
  */
 void
 adw_preferences_window_set_visible_page (AdwPreferencesWindow *self,
@@ -841,8 +821,6 @@ adw_preferences_window_set_visible_page (AdwPreferencesWindow *self,
  * Gets the name of currently visible page of @self.
  *
  * Returns: (transfer none) (nullable): the name of the visible page
- *
- * Since: 1.0
  */
 const char *
 adw_preferences_window_get_visible_page_name (AdwPreferencesWindow *self)
@@ -864,8 +842,6 @@ adw_preferences_window_get_visible_page_name (AdwPreferencesWindow *self)
  * Makes the page with the given name visible.
  *
  * See [property@ViewStack:visible-child].
- *
- * Since: 1.0
  */
 void
 adw_preferences_window_set_visible_page_name (AdwPreferencesWindow *self,
@@ -887,8 +863,6 @@ adw_preferences_window_set_visible_page_name (AdwPreferencesWindow *self,
  * Gets whether search is enabled for @self.
  *
  * Returns: whether search is enabled for @self.
- *
- * Since: 1.0
  */
 gboolean
 adw_preferences_window_get_search_enabled (AdwPreferencesWindow *self)
@@ -908,8 +882,6 @@ adw_preferences_window_get_search_enabled (AdwPreferencesWindow *self)
  * @search_enabled: whether search is enabled
  *
  * Sets whether search is enabled for @self.
- *
- * Since: 1.0
  */
 void
 adw_preferences_window_set_search_enabled (AdwPreferencesWindow *self,
@@ -955,8 +927,6 @@ adw_preferences_window_set_search_enabled (AdwPreferencesWindow *self,
  * <kbd>Alt</kbd>+<kbd>←</kbd> shortcut.
  *
  * For right-to-left locales, gestures and shortcuts are reversed.
- *
- * Since: 1.0
  */
 void
 adw_preferences_window_set_can_navigate_back (AdwPreferencesWindow *self,
@@ -985,8 +955,6 @@ adw_preferences_window_set_can_navigate_back (AdwPreferencesWindow *self,
  * Gets whether gestures and shortcuts for closing subpages are enabled.
  *
  * Returns: whether gestures and shortcuts are enabled.
- *
- * Since: 1.0
  */
 gboolean
 adw_preferences_window_get_can_navigate_back (AdwPreferencesWindow *self)
@@ -1009,8 +977,6 @@ adw_preferences_window_get_can_navigate_back (AdwPreferencesWindow *self)
  *
  * The transition can be cancelled by the user, in which case visible child will
  * change back to the previously visible child.
- *
- * Since: 1.0
  */
 void
 adw_preferences_window_present_subpage (AdwPreferencesWindow *self,
@@ -1044,8 +1010,6 @@ adw_preferences_window_present_subpage (AdwPreferencesWindow *self,
  * Closes the current subpage.
  *
  * If there is no presented subpage, this does nothing.
- *
- * Since: 1.0
  */
 void
 adw_preferences_window_close_subpage (AdwPreferencesWindow *self)
@@ -1070,8 +1034,6 @@ adw_preferences_window_close_subpage (AdwPreferencesWindow *self)
  * Displays @toast.
  *
  * See [method@ToastOverlay.add_toast].
- *
- * Since: 1.0
  */
 void
 adw_preferences_window_add_toast (AdwPreferencesWindow *self,
@@ -1085,3 +1047,4 @@ adw_preferences_window_add_toast (AdwPreferencesWindow *self,
 
   adw_toast_overlay_add_toast (priv->toast_overlay, toast);
 }
+
