@@ -48,17 +48,6 @@
  * classes matching the button contents. The nested button nodes will never
  * contain them.
  *
- * ## Style classes
- *
- * `AdwSplitButton` can use some of the same style classes as [class@Gtk.Button]:
- *
- * - [`.suggested-action`](style-classes.html#suggested-action)
- * - [`.destructive-action`](style-classes.html#destructive-action)
- * - [`.flat`](style-classes.html#flat)
- * - [`.raised`](style-classes.html#raised)
- *
- * Other style classes, like `.pill`, cannot be used.
- *
  * ## Accessibility
  *
  * `AdwSplitButton` uses the `GTK_ACCESSIBLE_ROLE_GROUP` role.
@@ -70,7 +59,6 @@ enum {
   PROP_USE_UNDERLINE,
   PROP_ICON_NAME,
   PROP_CHILD,
-  PROP_CAN_SHRINK,
   PROP_MENU_MODEL,
   PROP_POPOVER,
   PROP_DIRECTION,
@@ -196,9 +184,6 @@ adw_split_button_get_property (GObject    *object,
   case PROP_CHILD:
     g_value_set_object (value, adw_split_button_get_child (self));
     break;
-  case PROP_CAN_SHRINK:
-    g_value_set_boolean (value, adw_split_button_get_can_shrink (self));
-    break;
   case PROP_MENU_MODEL:
     g_value_set_object (value, adw_split_button_get_menu_model (self));
     break;
@@ -244,9 +229,6 @@ adw_split_button_set_property (GObject      *object,
   case PROP_CHILD:
     adw_split_button_set_child (self, g_value_get_object (value));
     break;
-  case PROP_CAN_SHRINK:
-    adw_split_button_set_can_shrink (self, g_value_get_boolean (value));
-    break;
   case PROP_MENU_MODEL:
     adw_split_button_set_menu_model (self, g_value_get_object (value));
     break;
@@ -300,7 +282,7 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
   widget_class->compute_expand = adw_widget_compute_expand;
 
   /**
-   * AdwSplitButton:label:
+   * AdwSplitButton:label: (attributes org.gtk.Property.get=adw_split_button_get_label org.gtk.Property.set=adw_split_button_set_label)
    *
    * The label for the button.
    *
@@ -313,7 +295,7 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSplitButton:use-underline:
+   * AdwSplitButton:use-underline: (attributes org.gtk.Property.get=adw_split_button_get_use_underline org.gtk.Property.set=adw_split_button_set_use_underline)
    *
    * Whether an underline in the text indicates a mnemonic.
    *
@@ -325,7 +307,7 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSplitButton:icon-name:
+   * AdwSplitButton:icon-name: (attributes org.gtk.Property.get=adw_split_button_get_icon_name org.gtk.Property.set=adw_split_button_set_icon_name)
    *
    * The name of the icon used to automatically populate the button.
    *
@@ -338,7 +320,7 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSplitButton:child:
+   * AdwSplitButton:child: (attributes org.gtk.Property.get=adw_split_button_get_child org.gtk.Property.set=adw_split_button_set_child)
    *
    * The child widget.
    *
@@ -351,24 +333,7 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSplitButton:can-shrink:
-   *
-   * Whether the button can be smaller than the natural size of its contents.
-   *
-   * If set to `TRUE`, the label will ellipsize.
-   *
-   * See [property@Gtk.Button:can-shrink] and
-   * [property@Gtk.MenuButton:can-shrink].
-   *
-   * Since: 1.4
-   */
-  props[PROP_CAN_SHRINK] =
-    g_param_spec_boolean ("can-shrink", NULL, NULL,
-                          FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
-
-  /**
-   * AdwSplitButton:menu-model:
+   * AdwSplitButton:menu-model: (attributes org.gtk.Property.get=adw_split_button_get_menu_model org.gtk.Property.set=adw_split_button_set_menu_model)
    *
    * The `GMenuModel` from which the popup will be created.
    *
@@ -387,7 +352,7 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSplitButton:popover:
+   * AdwSplitButton:popover: (attributes org.gtk.Property.get=adw_split_button_get_popover org.gtk.Property.set=adw_split_button_set_popover)
    *
    * The `GtkPopover` that will be popped up when the dropdown is clicked.
    *
@@ -402,7 +367,7 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSplitButton:direction:
+   * AdwSplitButton:direction: (attributes org.gtk.Property.get=adw_split_button_get_direction org.gtk.Property.set=adw_split_button_set_direction)
    *
    * The direction in which the popup will be popped up.
    *
@@ -420,7 +385,7 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSplitButton:dropdown-tooltip:
+   * AdwSplitButton:dropdown-tooltip: (attributes org.gtk.Property.get=adw_split_button_get_dropdown_tooltip org.gtk.Property.set=adw_split_button_set_dropdown_tooltip)
    *
    * The tooltip of the dropdown button.
    *
@@ -628,7 +593,7 @@ adw_split_button_new (void)
 }
 
 /**
- * adw_split_button_get_label:
+ * adw_split_button_get_label: (attributes org.gtk.Method.get_property=label)
  * @self: a split button
  *
  * Gets the label for @self.
@@ -644,7 +609,7 @@ adw_split_button_get_label (AdwSplitButton *self)
 }
 
 /**
- * adw_split_button_set_label:
+ * adw_split_button_set_label: (attributes org.gtk.Method.set_property=label)
  * @self: a split button
  * @label: the label to set
  *
@@ -677,7 +642,7 @@ adw_split_button_set_label (AdwSplitButton *self,
 }
 
 /**
- * adw_split_button_get_use_underline:
+ * adw_split_button_get_use_underline: (attributes org.gtk.Method.get_property=use-underline)
  * @self: a split button
  *
  * Gets whether an underline in the text indicates a mnemonic.
@@ -693,7 +658,7 @@ adw_split_button_get_use_underline (AdwSplitButton *self)
 }
 
 /**
- * adw_split_button_set_use_underline:
+ * adw_split_button_set_use_underline: (attributes org.gtk.Method.set_property=use-underline)
  * @self: a split button
  * @use_underline: whether an underline in the text indicates a mnemonic
  *
@@ -716,7 +681,7 @@ adw_split_button_set_use_underline (AdwSplitButton *self,
 }
 
 /**
- * adw_split_button_get_icon_name:
+ * adw_split_button_get_icon_name: (attributes org.gtk.Method.get_property=icon-name)
  * @self: a split button
  *
  * Gets the name of the icon used to automatically populate the button.
@@ -732,7 +697,7 @@ adw_split_button_get_icon_name (AdwSplitButton *self)
 }
 
 /**
- * adw_split_button_set_icon_name:
+ * adw_split_button_set_icon_name: (attributes org.gtk.Method.set_property=icon-name)
  * @self: a split button
  * @icon_name: the icon name to set
  *
@@ -766,7 +731,7 @@ adw_split_button_set_icon_name (AdwSplitButton *self,
 }
 
 /**
- * adw_split_button_get_child:
+ * adw_split_button_get_child: (attributes org.gtk.Method.get_property=child)
  * @self: a split button
  *
  * Gets the child widget.
@@ -782,7 +747,7 @@ adw_split_button_get_child (AdwSplitButton *self)
 }
 
 /**
- * adw_split_button_set_child:
+ * adw_split_button_set_child: (attributes org.gtk.Method.set_property=child)
  * @self: a split button
  * @child: (nullable): the new child widget
  *
@@ -796,14 +761,10 @@ adw_split_button_set_child (AdwSplitButton *self,
                             GtkWidget      *child)
 {
   g_return_if_fail (ADW_IS_SPLIT_BUTTON (self));
-  g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
 
   if (child == adw_split_button_get_child (self))
     return;
 
-  if (child)
-    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
-
   g_object_freeze_notify (G_OBJECT (self));
   if (adw_split_button_get_label (self))
     g_object_notify_by_pspec (G_OBJECT (self), props[PROP_LABEL]);
@@ -819,55 +780,7 @@ adw_split_button_set_child (AdwSplitButton *self,
 }
 
 /**
- * adw_split_button_get_can_shrink:
- * @self: a split button
- *
- * gets whether the button can be smaller than the natural size of its contents.
- *
- * Returns: whether the button can shrink
- *
- * Since: 1.4
- */
-gboolean
-adw_split_button_get_can_shrink (AdwSplitButton *self)
-{
-  g_return_val_if_fail (ADW_IS_SPLIT_BUTTON (self), FALSE);
-
-  return gtk_button_get_can_shrink (GTK_BUTTON (self->button));
-}
-
-/**
- * adw_split_button_set_can_shrink:
- * @self: a split button
- * @can_shrink: whether the button can shrink
- *
- * Sets whether the button can be smaller than the natural size of its contents.
- *
- * If set to `TRUE`, the label will ellipsize.
- *
- * See [method@Gtk.Button.set_can_shrink] and
- * [method@Gtk.MenuButton.set_can_shrink].
- *
- * Since: 1.4
- */
-void
-adw_split_button_set_can_shrink (AdwSplitButton *self,
-                                 gboolean        can_shrink)
-{
-  g_return_if_fail (ADW_IS_SPLIT_BUTTON (self));
-
-  can_shrink = !!can_shrink;
-
-  if (can_shrink == adw_split_button_get_can_shrink (self))
-    return;
-
-  gtk_button_set_can_shrink (GTK_BUTTON (self->button), can_shrink);
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CAN_SHRINK]);
-}
-
-/**
- * adw_split_button_get_menu_model:
+ * adw_split_button_get_menu_model: (attributes org.gtk.Method.get_property=menu-model)
  * @self: a split button
  *
  * Gets the menu model from which the popup will be created.
@@ -883,7 +796,7 @@ adw_split_button_get_menu_model (AdwSplitButton *self)
 }
 
 /**
- * adw_split_button_set_menu_model:
+ * adw_split_button_set_menu_model: (attributes org.gtk.Method.set_property=menu-model)
  * @self: a split button
  * @menu_model: (nullable): the menu model
  *
@@ -911,7 +824,7 @@ adw_split_button_set_menu_model (AdwSplitButton *self,
 }
 
 /**
- * adw_split_button_get_popover:
+ * adw_split_button_get_popover: (attributes org.gtk.Method.get_property=popover)
  * @self: a split button
  *
  * Gets the popover that will be popped up when the dropdown is clicked.
@@ -927,7 +840,7 @@ adw_split_button_get_popover (AdwSplitButton *self)
 }
 
 /**
- * adw_split_button_set_popover:
+ * adw_split_button_set_popover: (attributes org.gtk.Method.set_property=popover)
  * @self: a split button
  * @popover: (nullable): the popover
  *
@@ -951,7 +864,7 @@ adw_split_button_set_popover (AdwSplitButton *self,
 }
 
 /**
- * adw_split_button_get_direction:
+ * adw_split_button_get_direction: (attributes org.gtk.Method.get_property=direction)
  * @self: a split button
  *
  * Gets the direction in which the popup will be popped up.
@@ -967,7 +880,7 @@ adw_split_button_get_direction (AdwSplitButton *self)
 }
 
 /**
- * adw_split_button_set_direction:
+ * adw_split_button_set_direction: (attributes org.gtk.Method.set_property=direction)
  * @self: a split button
  * @direction: the direction
  *
@@ -995,7 +908,7 @@ adw_split_button_set_direction (AdwSplitButton *self,
 }
 
 /**
- * adw_split_button_get_dropdown_tooltip:
+ * adw_split_button_get_dropdown_tooltip: (attributes org.gtk.Method.get_property=dropdown-tooltip)
  * @self: a split button
  *
  * Gets the tooltip of the dropdown button of @self.
@@ -1016,7 +929,7 @@ adw_split_button_get_dropdown_tooltip (AdwSplitButton *self)
 }
 
 /**
- * adw_split_button_set_dropdown_tooltip:
+ * adw_split_button_set_dropdown_tooltip: (attributes org.gtk.Method.set_property=dropdown-tooltip)
  * @self: a split button
  * @tooltip: the dropdown tooltip of @self
  *
