@@ -135,33 +135,7 @@ ADW_AVAILABLE_IN_ALL
 void     adw_view_stack_set_vhomogeneous (AdwViewStack *self,
                                           gboolean      vhomogeneous);
 
-ADW_AVAILABLE_IN_1_7
-gboolean adw_view_stack_get_enable_transitions (AdwViewStack *self);
-ADW_AVAILABLE_IN_1_7
-void     adw_view_stack_set_enable_transitions (AdwViewStack *self,
-                                                gboolean      enable_transitions);
-
-ADW_AVAILABLE_IN_1_7
-guint adw_view_stack_get_transition_duration (AdwViewStack *self);
-ADW_AVAILABLE_IN_1_7
-void  adw_view_stack_set_transition_duration (AdwViewStack *self,
-                                              guint         duration);
-
-ADW_AVAILABLE_IN_1_7
-gboolean adw_view_stack_get_transition_running (AdwViewStack *self);
-
 ADW_AVAILABLE_IN_ALL
 GtkSelectionModel *adw_view_stack_get_pages (AdwViewStack *self);
 
-#define ADW_TYPE_VIEW_STACK_PAGES (adw_view_stack_pages_get_type ())
-
-ADW_AVAILABLE_IN_1_4
-G_DECLARE_FINAL_TYPE (AdwViewStackPages, adw_view_stack_pages, ADW, VIEW_STACK_PAGES, GObject)
-
-ADW_AVAILABLE_IN_1_4
-AdwViewStackPage *adw_view_stack_pages_get_selected_page (AdwViewStackPages *self);
-ADW_AVAILABLE_IN_1_4
-void              adw_view_stack_pages_set_selected_page (AdwViewStackPages *self,
-                                                          AdwViewStackPage  *page);
-
 G_END_DECLS
